summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMartin Jones <martin.jones@nokia.com>2010-04-01 02:48:03 (GMT)
committerMartin Jones <martin.jones@nokia.com>2010-04-01 02:48:03 (GMT)
commita26d7ada2ece592ae9447b4eae95c3add61a34d7 (patch)
tree784e0732276ea08b3daa336ccec87ccaa17896a1
parentb5117243a50cca51cf8f77d153f0c400084134ef (diff)
parent67db3dc3b25e577a8389974bd06df9cd4b43059e (diff)
downloadQt-a26d7ada2ece592ae9447b4eae95c3add61a34d7.zip
Qt-a26d7ada2ece592ae9447b4eae95c3add61a34d7.tar.gz
Qt-a26d7ada2ece592ae9447b4eae95c3add61a34d7.tar.bz2
Merge branch '4.7' of scm.dev.nokia.troll.no:qt/qt-qml into 4.7
-rw-r--r--demos/declarative/minehunt/minehunt.pro2
-rw-r--r--doc/src/declarative/modules.qdoc2
-rw-r--r--examples/declarative/declarative.pro2
-rw-r--r--examples/declarative/imageprovider/imageprovider.pro4
-rw-r--r--examples/declarative/plugins/plugin.cpp18
-rw-r--r--examples/declarative/plugins/plugins.pro7
-rw-r--r--examples/declarative/proxywidgets/ProxyWidgets/qmldir1
-rw-r--r--examples/declarative/proxywidgets/README (renamed from examples/declarative/widgets/README)2
-rw-r--r--examples/declarative/proxywidgets/proxywidgets.cpp (renamed from examples/declarative/widgets/mywidgets.cpp)6
-rw-r--r--examples/declarative/proxywidgets/proxywidgets.pro (renamed from examples/declarative/widgets/mywidgets.pro)11
-rw-r--r--examples/declarative/proxywidgets/proxywidgets.qml (renamed from examples/declarative/widgets/mywidgets.qml)2
-rw-r--r--examples/declarative/widgets/MyWidgets/qmldir1
-rw-r--r--src/declarative/graphicsitems/qdeclarativeanchors.cpp4
-rw-r--r--tests/auto/declarative/qdeclarativeanchors/tst_qdeclarativeanchors.cpp4
-rw-r--r--tests/auto/declarative/qdeclarativetextinput/tst_qdeclarativetextinput.cpp2
-rw-r--r--tests/auto/declarative/qdeclarativevaluetypes/tst_qdeclarativevaluetypes.cpp1
16 files changed, 37 insertions, 32 deletions
diff --git a/demos/declarative/minehunt/minehunt.pro b/demos/declarative/minehunt/minehunt.pro
index 03059c7..da46dfc 100644
--- a/demos/declarative/minehunt/minehunt.pro
+++ b/demos/declarative/minehunt/minehunt.pro
@@ -9,7 +9,6 @@ DESTDIR = MinehuntCore
# Input
SOURCES += minehunt.cpp
-
sources.files = minehunt.qml minehunt.pro
sources.path = $$[QT_INSTALL_DEMOS]/declarative/minehunt
@@ -26,7 +25,6 @@ INSTALLS = sources MinehuntCore_sources target
symbian:{
load(data_caging_paths)
TARGET.EPOCALLOWDLLDATA = 1
- TARGET.CAPABILITY = CAP_GENERAL_DLL
include($$QT_SOURCE_TREE/demos/symbianpkgrules.pri)
importFiles.sources = minehunt.dll \
diff --git a/doc/src/declarative/modules.qdoc b/doc/src/declarative/modules.qdoc
index 13658d8..6b2e64e 100644
--- a/doc/src/declarative/modules.qdoc
+++ b/doc/src/declarative/modules.qdoc
@@ -83,7 +83,7 @@ For either type of module, a \c qmldir file in the module directory defines the
optional for location modules, but only for local filesystem content or a single remote content with a namespace.
The second exception is explained in more detail in the section below on Namespaces.
-\seciont2 The Import Path
+\section2 The Import Path
Installed modules are searched for on the import path.
The \c -L option to the \l {Qt Declarative UI Runtime}{qml} runtime adds paths to the import path.
diff --git a/examples/declarative/declarative.pro b/examples/declarative/declarative.pro
index 5fc1cf0..00d3c05 100644
--- a/examples/declarative/declarative.pro
+++ b/examples/declarative/declarative.pro
@@ -6,7 +6,7 @@ SUBDIRS = \
imageprovider \
objectlistmodel \
plugins \
- widgets
+ proxywidgets
# These examples contain no C++ and can simply be copied
sources.files = \
diff --git a/examples/declarative/imageprovider/imageprovider.pro b/examples/declarative/imageprovider/imageprovider.pro
index 86dbcca..945a301 100644
--- a/examples/declarative/imageprovider/imageprovider.pro
+++ b/examples/declarative/imageprovider/imageprovider.pro
@@ -18,4 +18,8 @@ ImageProviderCore_sources.files = \
ImageProviderCore/qmldir
ImageProviderCore_sources.path = $$[QT_INSTALL_EXAMPLES]/declarative/imageprovider/ImageProviderCore
+symbian:{
+ TARGET.EPOCALLOWDLLDATA=1
+}
+
INSTALLS = sources ImageProviderCore_sources target
diff --git a/examples/declarative/plugins/plugins.pro b/examples/declarative/plugins/plugins.pro
index 877a5ce..c409d39 100644
--- a/examples/declarative/plugins/plugins.pro
+++ b/examples/declarative/plugins/plugins.pro
@@ -8,7 +8,7 @@ VERSION = 1.0.0
SOURCES += plugin.cpp
qdeclarativesources.files += \
- com/nokia/TimeExample/qdeclarativedir \
+ com/nokia/TimeExample/qmldir \
com/nokia/TimeExample/center.png \
com/nokia/TimeExample/clock.png \
com/nokia/TimeExample/Clock.qml \
@@ -22,6 +22,11 @@ sources.path += $$[QT_INSTALL_EXAMPLES]/declarative/plugins
target.path += $$[QT_INSTALL_EXAMPLES]/declarative/plugins/com/nokia/TimeExample
+symbian:{
+ TARGET.EPOCALLOWDLLDATA=1
+}
+
+
INSTALLS += qdeclarativesources sources target
symbian: include($$QT_SOURCE_TREE/examples/symbianpkgrules.pri)
diff --git a/examples/declarative/proxywidgets/ProxyWidgets/qmldir b/examples/declarative/proxywidgets/ProxyWidgets/qmldir
new file mode 100644
index 0000000..e55267c
--- /dev/null
+++ b/examples/declarative/proxywidgets/ProxyWidgets/qmldir
@@ -0,0 +1 @@
+plugin proxywidgetsplugin
diff --git a/examples/declarative/widgets/README b/examples/declarative/proxywidgets/README
index f85a1e8..f50fa22 100644
--- a/examples/declarative/widgets/README
+++ b/examples/declarative/proxywidgets/README
@@ -1,4 +1,4 @@
To run:
make install
- qml mywidgets.qml
+ qml proxywidgets.qml
diff --git a/examples/declarative/widgets/mywidgets.cpp b/examples/declarative/proxywidgets/proxywidgets.cpp
index e17240d..47d0cb9 100644
--- a/examples/declarative/widgets/mywidgets.cpp
+++ b/examples/declarative/proxywidgets/proxywidgets.cpp
@@ -82,7 +82,7 @@ private:
QPushButton *widget;
};
-class MyWidgetsPlugin : public QDeclarativeExtensionPlugin
+class ProxyWidgetsPlugin : public QDeclarativeExtensionPlugin
{
Q_OBJECT
public:
@@ -92,8 +92,8 @@ public:
}
};
-#include "mywidgets.moc"
+#include "proxywidgets.moc"
QML_DECLARE_TYPE(MyPushButton)
-Q_EXPORT_PLUGIN2(mywidgetsplugin, MyWidgetsPlugin);
+Q_EXPORT_PLUGIN2(proxywidgetsplugin, ProxyWidgetsPlugin);
diff --git a/examples/declarative/widgets/mywidgets.pro b/examples/declarative/proxywidgets/proxywidgets.pro
index 258edb1..eb85191 100644
--- a/examples/declarative/widgets/mywidgets.pro
+++ b/examples/declarative/proxywidgets/proxywidgets.pro
@@ -1,13 +1,13 @@
TEMPLATE = lib
-DESTDIR = MyWidgets
-TARGET = mywidgetsplugin
+DESTDIR = ProxyWidgets
+TARGET = proxywidgetsplugin
CONFIG += qt plugin
QT += declarative
VERSION = 1.0.0
-SOURCES += mywidgets.cpp
+SOURCES += proxywidgets.cpp
-sources.files += mywidgets.pro mywidgets.cpp mywidgets.qml
+sources.files += proxywidgets.pro proxywidgets.cpp proxywidgets.qml
sources.path += $$[QT_INSTALL_EXAMPLES]/declarative/plugins
@@ -17,3 +17,6 @@ INSTALLS += sources target
symbian: include($$QT_SOURCE_TREE/examples/symbianpkgrules.pri)
+symbian:{
+ TARGET.EPOCALLOWDLLDATA = 1
+} \ No newline at end of file
diff --git a/examples/declarative/widgets/mywidgets.qml b/examples/declarative/proxywidgets/proxywidgets.qml
index b1efed4..023de71 100644
--- a/examples/declarative/widgets/mywidgets.qml
+++ b/examples/declarative/proxywidgets/proxywidgets.qml
@@ -1,5 +1,5 @@
import Qt 4.6
-import "MyWidgets" 1.0
+import "ProxyWidgets" 1.0
Rectangle {
id: window
diff --git a/examples/declarative/widgets/MyWidgets/qmldir b/examples/declarative/widgets/MyWidgets/qmldir
deleted file mode 100644
index dc1d10e..0000000
--- a/examples/declarative/widgets/MyWidgets/qmldir
+++ /dev/null
@@ -1 +0,0 @@
-plugin mywidgetsplugin
diff --git a/src/declarative/graphicsitems/qdeclarativeanchors.cpp b/src/declarative/graphicsitems/qdeclarativeanchors.cpp
index dc1f09d..ffcedda 100644
--- a/src/declarative/graphicsitems/qdeclarativeanchors.cpp
+++ b/src/declarative/graphicsitems/qdeclarativeanchors.cpp
@@ -1059,7 +1059,7 @@ bool QDeclarativeAnchorsPrivate::checkVAnchorValid(QDeclarativeAnchorLine anchor
return true;
}
-#include <moc_qdeclarativeanchors_p.cpp>
-
QT_END_NAMESPACE
+#include <moc_qdeclarativeanchors_p.cpp>
+
diff --git a/tests/auto/declarative/qdeclarativeanchors/tst_qdeclarativeanchors.cpp b/tests/auto/declarative/qdeclarativeanchors/tst_qdeclarativeanchors.cpp
index 6b7d57f..16ae7fc 100644
--- a/tests/auto/declarative/qdeclarativeanchors/tst_qdeclarativeanchors.cpp
+++ b/tests/auto/declarative/qdeclarativeanchors/tst_qdeclarativeanchors.cpp
@@ -390,7 +390,7 @@ void tst_qdeclarativeanchors::fill()
QCOMPARE(rect->y(), 0.0 + 30.0);
QCOMPARE(rect->width(), 200.0 - 10.0 - 20.0);
QCOMPARE(rect->height(), 200.0 - 30.0 - 40.0);
- //Alter Offsets (QTBUG-6631)
+ //Alter Offsets (tests QTBUG-6631)
rect->anchors()->setLeftMargin(20.0);
rect->anchors()->setRightMargin(0.0);
rect->anchors()->setBottomMargin(0.0);
@@ -411,7 +411,7 @@ void tst_qdeclarativeanchors::centerIn()
QDeclarativeRectangle* rect = findItem<QDeclarativeRectangle>(view->rootObject(), QLatin1String("centered"));
QCOMPARE(rect->x(), 75.0 + 10);
QCOMPARE(rect->y(), 75.0 + 30);
- //Alter Offsets (QTBUG-6631)
+ //Alter Offsets (tests QTBUG-6631)
rect->anchors()->setHorizontalCenterOffset(-20.0);
rect->anchors()->setVerticalCenterOffset(-10.0);
QCOMPARE(rect->x(), 75.0 - 20.0);
diff --git a/tests/auto/declarative/qdeclarativetextinput/tst_qdeclarativetextinput.cpp b/tests/auto/declarative/qdeclarativetextinput/tst_qdeclarativetextinput.cpp
index 84e7182..b6f55dd 100644
--- a/tests/auto/declarative/qdeclarativetextinput/tst_qdeclarativetextinput.cpp
+++ b/tests/auto/declarative/qdeclarativetextinput/tst_qdeclarativetextinput.cpp
@@ -523,7 +523,7 @@ void tst_qdeclarativetextinput::navigation()
QVERIFY(input->hasFocus() == false);
simulateKey(canvas, Qt::Key_Right);
QVERIFY(input->hasFocus() == true);
- //QT-2944: If text is selected, then we should deselect first.
+ //QT-2944: If text is selected, ensure we deselect upon cursor motion
input->setCursorPosition(input->text().length());
input->setSelectionStart(0);
input->setSelectionEnd(input->text().length());
diff --git a/tests/auto/declarative/qdeclarativevaluetypes/tst_qdeclarativevaluetypes.cpp b/tests/auto/declarative/qdeclarativevaluetypes/tst_qdeclarativevaluetypes.cpp
index a5cb16f..4e254eb 100644
--- a/tests/auto/declarative/qdeclarativevaluetypes/tst_qdeclarativevaluetypes.cpp
+++ b/tests/auto/declarative/qdeclarativevaluetypes/tst_qdeclarativevaluetypes.cpp
@@ -432,7 +432,6 @@ void tst_qdeclarativevaluetypes::autoBindingRemoval()
object->setProperty("value", QVariant(92));
- //QEXPECT_FAIL("", "QT-2920", Continue);
QCOMPARE(object->rect().x(), 42);
delete object;
diff --git a/examples/declarative/plugins/plugin.cpp b/examples/declarative/plugins/plugin.cpp
index 741f68a..fb51b0c 100644
--- a/examples/declarative/plugins/plugin.cpp
+++ b/examples/declarative/plugins/plugin.cpp
@@ -46,7 +46,7 @@
#include <qbasictimer.h>
#include <qapplication.h>
// Implements a "Time" class with hour and minute properties
// that change on-the-minute yet efficiently sleep the rest
// of the time.
@@ -97,14 +97,14 @@ private:
QBasicTimer timer;
};
-class Time : public QObject
+class TimeModel : public QObject
{
Q_OBJECT
Q_PROPERTY(int hour READ hour NOTIFY timeChanged)
Q_PROPERTY(int minute READ minute NOTIFY timeChanged)
public:
- Time(QObject *parent=0) : QObject(parent)
+ TimeModel(QObject *parent=0) : QObject(parent)
{
if (++instances == 1) {
if (!timer)
@@ -114,7 +114,7 @@ public:
}
}
- ~Time()
+ ~TimeModel()
{
if (--instances == 0) {
timer->stop();
@@ -133,12 +133,8 @@ private:
static int instances;
};
-int Time::instances=0;
-MinuteTimer *Time::timer=0;
-
-
-QML_DECLARE_TYPE(Time);
-
+int TimeModel::instances=0;
+MinuteTimer *TimeModel::timer=0;
class QExampleQmlPlugin : public QDeclarativeExtensionPlugin
{
@@ -147,7 +143,7 @@ public:
void registerTypes(const char *uri)
{
Q_ASSERT(uri == QLatin1String("com.nokia.TimeExample"));
- qmlRegisterType<Time>(uri, 1, 0, "Time");
+ qmlRegisterType<TimeModel>(uri, 1, 0, "Time");
}
};
@@ -46,7 +46,7 @@
#include <qbasictimer.h>
#include <qapplication.h>
-// Implements a "Time" class with hour and minute properties
+// Implements a "TimeModel" class with hour and minute properties
// that change on-the-minute yet efficiently sleep the rest
// of the time.